==============
atsphinx-bulma
==============

Overview
========

atsphinx-bulma is Sphinx extension for html-based builder to improve contents by Bulma.

Installation
============

You can install from PyPI by your package manager.

.. code-block:: console

   pip install atsphinx-bulma

.. code-block:: console

   uv add atsphinx-bulma

Features and usage
==================

.. toctree::
   :maxdepth: 2

   theme
   elements/index
   components/index

.. todo::

   Require docs for components and widgets.

.. toctree::
   :hidden:

   changes
